=========
Holoviews
=========

Plotting with holoviews.

.. report:: Tutorial9.ExpressionLevels
   :render: hvplot
   :statement: hv.Scatter(data)

   A scatter plot.


.. report:: Tutorial9.ExpressionLevels
   :render: hvplot
   :statement: hv.Scatter(data) + hv.Curve(data)

   Side-by-side


.. report:: Tutorial9.ExpressionLevels
   :render: Holoviews.HvPlotScatterWithLabels

   A user customized plot - showing labels


.. report:: Tutorial9.ExpressionLevels
   :render: Holoviews.HvPlotScatterWithHover

   A user customized plot - showing hovering and changing size
	    

